.citation {
    background-color: rgba(0, 0, 0, 0.1) !important;
    border: 1px solid black;
    margin: 0 10%;
    padding:10px;
    border-radius: 5px;
}

.citation > * {
    margin: 0 !important;
}

.link_citation {
	display: inline-block;
    width: 90%;
    text-align: right;
    font-weight: normal;
}

.not_found {
    background-color: rgba(211, 211, 211, 0.521);
    display: inline;
    color: grey;
    border-radius: 5px;
    padding: 5px;
}

